import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {DescItem} from "@/components/Description";
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
    slots: { customRender: 'name' },
  },
  {
    title: '状态',
    dataIndex: 'flag',
    width: 120,
    slots: { customRender: 'flag' },  // 使用自定义插槽
  },
  {
    title: '模式',
    dataIndex: 'mode',
    width: 120,
  },
  {
    title: '超时时间',
    dataIndex: 'timeout',
    width: 120,
  },
  {
    title: '上线版本号',
    dataIndex: 'versionNum',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 180,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 180,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 120,
  },
];
/** 筛选展示字段*/

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名称',
      },
    ],
  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '描述',
    componentProps: {
      placeholder: '请输入描述',
      rows: 4,
    },
  },
  {
    field: 'sort',
    label: '最低安全分级',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择推荐保护动作',
      },
    ],
  },
  {
    field: 'protectAction',
    label: '推荐脱敏算法',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'BlockFront', value: 'BlockFront' },
        { label: 'Delete', value: 'Delete' },
        { label: 'Mask', value: 'Mask' },
        { label: 'Base64', value: 'Base64' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择推荐保护动作',
      },
    ],
  },
  {
    field: 'params',
    label: '算法参数',
    component: 'Input',

  },
]

export const modelFormSchema: FormSchema[] = [
  {
    field: 'member',
    component: 'InputSearch',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const modelColumns: BasicColumn[] = [
  {
    title: 'member',
    dataIndex: 'member',
    slots: { customRender: 'member' },
  },
];
export const Table1Schema: BasicColumn[] = [
  {
    title: '字段名称',
    width: 150,
    dataIndex: 'name',
  },
  {
    title: '敏感状态',
    width: 120,
    dataIndex: 'stsensitiveStatusatic',
  },
  {
    title: '安全分级',
    width: 120,
    dataIndex: 'securityGrading',
  },
  {
    title: '敏感类型',
    width: 120,
    dataIndex: 'sensitivityType',
  },
];
export const Table2Schema: BasicColumn[] = [
  {
    title: '字段名称',
    width: 150,
    dataIndex: 'name',
  },
  {
    title: '敏感状态',
    width: 120,
    dataIndex: 'stsensitiveStatusatic',
  },
  {
    title: '安全分级',
    width: 120,
    dataIndex: 'securityGrading',
  },
  {
    title: '敏感类型',
    width: 120,
    dataIndex: 'sensitivityType',
  },
];
export const Table3Schema: BasicColumn[] = [
  {
    title: '参数code',
    width: 150,
    dataIndex: 'code',
  },
  {
    title: '参数名称',
    width: 120,
    dataIndex: 'codeName',
  },
  {
    title: '参数类型',
    width: 120,
    dataIndex: 'type',
  },
  {
    title: '注释',
    width: 120,
    dataIndex: 'comment',
  },
  {
    title: '是否必填',
    width: 120,
    dataIndex: 'required',
  },
  {
    title: '参数值',
    width: 120,
    dataIndex: 'value',
  },
];

export const Table4Schema: BasicColumn[] = [
  {
    title: '参数code',
    width: 150,
    dataIndex: 'code',
  },
  {
    title: '参数名称',
    width: 120,
    dataIndex: 'codeName',
  },
  {
    title: '参数类型',
    width: 120,
    dataIndex: 'type',
  },
  {
    title: '是否必填',
    width: 120,
    dataIndex: 'required',
  },
  {
    title: '默认值',
    width: 120,
    dataIndex: 'defaultValue',
  },
];
export const apiDetailSchema: DescItem[] = [
  {
    field: 'a1',
    label: 'API版本号',
  },
  {
    field: 'a2',
    label: '超时时间',
  },
  {
    field: 'a3',
    label: 'API描述',
  },
  {
    field: 'a4',
    label: 'API模式',
  },
  {
    field: 'a5',
    label: '数据源',
  },
  {
    field: 'a6',
    label: '数据库',
  },

];
